summaryrefslogtreecommitdiffstats
path: root/kcontrol/colors
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:29:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:29:23 -0600
commit628043be55ddd2f534411d028e4f68c8fe4eaabb (patch)
tree29459652112ab6d5dfbf27ac0bbf5b86b7c83bca /kcontrol/colors
parent2c01fd64ddde84a6d78b632f7f3b7c3560dc288c (diff)
downloadtdebase-628043be55ddd2f534411d028e4f68c8fe4eaabb.tar.gz
tdebase-628043be55ddd2f534411d028e4f68c8fe4eaabb.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kcontrol/colors')
-rw-r--r--kcontrol/colors/widgetcanvas.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kcontrol/colors/widgetcanvas.cpp b/kcontrol/colors/widgetcanvas.cpp
index 450b140a5..ba1edfaf3 100644
--- a/kcontrol/colors/widgetcanvas.cpp
+++ b/kcontrol/colors/widgetcanvas.cpp
@@ -338,7 +338,7 @@ void WidgetCanvas::drawSampleWidgets()
smplw.resize(width(), height());
//smplw.fill( parentWidget()->back() );
- smplw.fill( parentWidget()->tqcolorGroup().mid() );
+ smplw.fill( parentWidget()->colorGroup().mid() );
// Actually start painting in
@@ -567,9 +567,9 @@ void WidgetCanvas::drawSampleWidgets()
popup->setItemEnabled( id, false );
// HACK: Force Layouting
- //Sad Eagle: tqsizeHint() forces layouting too, and it's a lot less visible
- //popup->tqsizeHint(); // Breaks with Qt 3.3
- popup->resize(popup->tqsizeHint());
+ //Sad Eagle: sizeHint() forces layouting too, and it's a lot less visible
+ //popup->sizeHint(); // Breaks with Qt 3.3
+ popup->resize(popup->sizeHint());
pm = TQPixmap::grabWidget( popup );
delete popup;
@@ -585,7 +585,7 @@ void WidgetCanvas::drawSampleWidgets()
// Valance
qDrawWinPanel ( &paint, 0, 0, width(), height(),
- parentWidget()->tqcolorGroup(), TRUE, 0);
+ parentWidget()->colorGroup(), TRUE, 0);
// Stop the painting